.. Licensed under the Apache License: http://www.apache.org/licenses/LICENSE-2.0
.. For details: https://github.com/coveragepy/coveragepy/blob/main/NOTICE.txt

.. _api_plugin:

===============
Plug-in classes
===============

.. automodule:: coverage.plugin

The CoveragePlugin class
------------------------

.. autoclass:: coverage.CoveragePlugin
    :members:
    :member-order: bysource

The FileTracer class
--------------------

.. autoclass:: coverage.FileTracer
    :members:
    :member-order: bysource

The FileReporter class
----------------------

.. autoclass:: coverage.FileReporter
    :members:
    :member-order: bysource

The CodeRegion class
--------------------

.. autoclass:: coverage.CodeRegion
    :members:
    :member-order: bysource
